==> freemedforms-project_0.7.1.orig.tar.gz: freemedforms-0.7.1/global_resources/translations/padtoolsplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>PadTools::Internal::PadWriter</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raw source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenari</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>raw to output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>output to raw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RAW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OUTPUT</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadTools::PadWriter</name>
    <message>
        <source>Next block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected &apos;%1&apos; found at pos %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &apos;%1&apos; at pos %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadTools::TokenEditor</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Token editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadTools::TokenEditorWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block formatting of the token value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conditionnal texts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadTools::TokenOutputDocument</name>
    <message>
        <source>Inside conditionnal before text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inside conditionnal after text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nested token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have dropped a token inside the value of a token. 
You must specify where the dropped token should be inserted:
- inside the conditionnal text before the token, 
- inside the conditionnal text after the token 
- or the before/after the token</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadWriter</name>
    <message>
        <source>Follow cursor in result output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic update of results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set a test value to all available tokens</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find cursor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/padtoolsplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>PadTools::Internal::PadWriter</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raw source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenari</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>raw to output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>output to raw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RAW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OUTPUT</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadTools::PadWriter</name>
    <message>
        <source>Next block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected &apos;%1&apos; found at pos %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &apos;%1&apos; at pos %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadTools::TokenEditor</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Token editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadTools::TokenEditorWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block formatting of the token value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conditionnal texts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PadWriter</name>
    <message>
        <source>Follow cursor in result output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic update of results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set a test value to all available tokens</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inside conditionnal before text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inside conditionnal after text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Before the token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After the token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nested token</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
